Copy cohorts from one table to another table. If the new cohort table has any cohort id that matches the cohort id being copied, an error will be displayed.
copyCohorts(
connectionDetails = NULL,
connection = NULL,
oldToNewCohortId,
sourceCohortDatabaseSchema = NULL,
targetCohortDatabaseSchema = sourceCohortDatabaseSchema,
sourceCohortTable,
targetCohortTable,
isTempTable = FALSE,
purgeConflicts = FALSE,
tempEmulationSchema = getOption("sqlRenderTempEmulationSchema")
)Nothing is returned
An object of type connectionDetails as created using the
createConnectionDetails function in the
DatabaseConnector package. Can be left NULL if connection is
provided.
An object of type connection as created using the
connect function in the
DatabaseConnector package. Can be left NULL if connectionDetails
is provided, in which case a new connection will be opened at the start
of the function, and closed when the function finishes.
A data.frame object with two columns. oldCohortId and newCohortId. Both should be integers. The oldCohortId are the cohorts that are the input cohorts that need to be transformed. The newCohortId are the cohortIds of the corresponding output after transformation. If the oldCohortId = newCohortId then the data corresponding to oldCohortId will be replaced by the data from the newCohortId.
The database schema of the source cohort table.
The database schema of the source cohort table.
The name of the source cohort table.
The name of the target cohort table.
Is the output a temp table. If yes, a new temp table is created. This will required an active connection. Any old temp table is dropped and replaced.
If there are conflicts in the target cohort table i.e. the target cohort table already has records with newCohortId, do you want to purge and replace them with transformed. By default - it will not be replaced, and an error message is thrown.
Some database platforms like Oracle and Impala do not truly support temp tables. To emulate temp tables, provide a schema with write privileges where temp tables can be created.